Density, distribution function, quantile function, and random
generation for the Tracy-Widom distribution with order parameter
beta.
dtw(x, beta=1, log = FALSE)
ptw(q, beta=1, lower.tail = TRUE, log.p = FALSE)
qtw(p, beta=1, lower.tail = TRUE, log.p = FALSE)
rtw(n, beta=1)dtw gives the density,
ptw gives the distribution function,
qtw gives the quantile function, and
rtw generates random deviates.
vector of quantiles.
vector of probabilities.
number of observations. If length(n) > 1, the length
is taken to be the number required.
the order parameter (1, 2, or 4).
logical; if TRUE, probabilities p are given as log(p).
logical; if TRUE (default), probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).
Iain M. Johnstone, Zongming Ma, Patrick O. Perry and Morteza Shahram
If beta is not specified, it assumes the default value of 1.
The Tracy-Widom law is the edge-scaled limiting distribution of the
largest eigenvalue of a random matrix from the \(\beta\)-ensemble.
Supported values for beta are 1 (Gaussian Orthogonal Ensemble),
2 (Gaussian Unitary Ensemble), and 4 (Gaussian Symplectic
Ensemble).
Dieng, M. (2006). Distribution functions for edge eigenvalues in orthogonal and symplectic ensembles: Painlevé representations. arXiv:math/0506586v2 [math.PR].
Tracy, C.A. and Widom, H. (1994). Level-spacing distributions and the Airy kernel. Communications in Mathematical Physics 159, 151--174.
Tracy, C.A. and Widom, H. (1996). On orthogonal and symplectic matrix ensembles. Communications in Mathematical Phsyics 177, 727--754.